%define major		13
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Tools for managing sets of IP or ports with iptables
Name:		ipset
Version:	7.10
Release:	%mkrel 1
License:	GPLv2+
Group:		System/Kernel and hardware
Url:		http://ipset.netfilter.org/
Source0:	http://ipset.netfilter.org/%{name}-%{version}.tar.bz2
Source10:	ipset.service
Source11:	ipset.init
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(libmnl)

%description
IP sets are a framework inside the Linux kernel since 2.4.x, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

ipset may be the proper tool for you, if you want to

 o store multiple IP addresses or port numbers and match against the collection
   by iptables at one swoop;

 o dynamically update iptables rules against IP addresses or ports without
   performance penalty;

 o express complex IP address and ports based rulesets with one single iptables
   rule and benefit from the speed of IP sets

%package -n	%{libname}
Summary:	Shared %{name} library
Group:          System/Libraries

%description -n	%{libname}
IP sets are a framework inside the Linux kernel since 2.4.x, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

This package contains the shared %{name} library.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Provides:	%{name}-devel = %{version}
Requires:	%{libname} >= %{version}

%description -n	%{develname}
IP sets are a framework inside the Linux kernel since 2.4.x, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

This package contains the development files for %{name}.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -vfi
%configure \
    --enable-bashcompl \
    --enable-shared \
    --disable-static \
    --enable-settype-modules \
    --with-settype-modules-list="all" \
    --with-kmod=no
%make_build

%install
%make_install

# install systemd unit file
install -Dpm644 %{_sourcedir}/ipset.service %{buildroot}%{_unitdir}/ipset.service

# install supporting script
install -Dpm755 %{_sourcedir}/ipset.init %{buildroot}%{_libexecdir}/ipset.init

# we don't want these
find %{buildroot} -name "*.la" -delete

%post
%systemd_post %{name}.service

%preun
if [[ $1 -eq 0 && -n $(lsmod | grep "^xt_set ") ]]; then
    rmmod xt_set 2>/dev/null
    [[ $? -ne 0 ]] && echo Current iptables configuration requires ipsets && exit 1
fi
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%files
%doc ChangeLog ChangeLog.ippool
%{_sbindir}/*
%{_mandir}/man8/*.8*
%{_unitdir}/ipset.service
%{_libexecdir}/ipset.init
%{_datadir}/bash-completion/completions/ipset

%dir %{_libdir}/%{name}
%{_libdir}/%{name}/%{name}_bitmap_ip.so
%{_libdir}/%{name}/%{name}_bitmap_ipmac.so
%{_libdir}/%{name}/%{name}_bitmap_port.so
%{_libdir}/%{name}/%{name}_hash_ip.so
%{_libdir}/%{name}/%{name}_hash_ipmac.so
%{_libdir}/%{name}/%{name}_hash_ipmark.so
%{_libdir}/%{name}/%{name}_hash_ipport.so
%{_libdir}/%{name}/%{name}_hash_ipportip.so
%{_libdir}/%{name}/%{name}_hash_ipportnet.so
%{_libdir}/%{name}/%{name}_hash_mac.so
%{_libdir}/%{name}/%{name}_hash_net.so
%{_libdir}/%{name}/%{name}_hash_netiface.so
%{_libdir}/%{name}/%{name}_hash_netnet.so
%{_libdir}/%{name}/%{name}_hash_netport.so
%{_libdir}/%{name}/%{name}_hash_netportnet.so
%{_libdir}/%{name}/%{name}_list_set.so

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%dir %{_includedir}/libipset/
%{_includedir}/libipset/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libipset.pc
%{_mandir}/man3/libipset.3*


%changelog
* Mon Dec 21 2020 wally <wally> 7.10-1.mga8
+ Revision: 1662603
- new version 7.10

* Sun Nov 29 2020 luigiwalser <luigiwalser> 7.9-1.mga8
+ Revision: 1650099
- 7.9
- library major is now 13

* Thu Nov 19 2020 luigiwalser <luigiwalser> 7.7-1.mga8
+ Revision: 1647417
- 7.7
- library major is now 12

* Thu May 28 2020 daviddavid <daviddavid> 7.6-1.mga8
+ Revision: 1588420
- new version: 7.6

* Thu Feb 20 2020 umeabot <umeabot> 7.5-2.mga8
+ Revision: 1546415
- Mageia 8 Mass Rebuild

* Sun Feb 02 2020 wally <wally> 7.5-1.mga8
+ Revision: 1486415
- new version 7.5
- replace deprecated %%configure2_5x

* Mon Aug 26 2019 wally <wally> 7.3-1.mga8
+ Revision: 1432472
- new version 7.3

* Sun Jan 06 2019 wally <wally> 7.1-1.mga7
+ Revision: 1350172
- new version 7.1
- new libmajor 13

* Sun Dec 30 2018 wally <wally> 6.38-3.mga7
+ Revision: 1347011
- skip kmod build
- add bash completion support
- add systemd service file and helper script based on ones in Fedora to restore
  ipset sets when booting

* Fri Dec 28 2018 wally <wally> 6.38-2.mga7
+ Revision: 1345697
- move internal modules to main pkg

* Fri Dec 28 2018 luigiwalser <luigiwalser> 6.38-1.mga7
+ Revision: 1345649
- 6.38
- library major is now 11

* Sun Sep 23 2018 umeabot <umeabot> 6.30-2.mga7
+ Revision: 1298313
- Mageia 7 Mass Rebuild

* Fri Nov 11 2016 luigiwalser <luigiwalser> 6.30-1.mga6
+ Revision: 1066559
- 6.30
- remove linking patch (fixed upstream)

* Tue Jan 05 2016 blino <blino> 6.27-3.mga6
+ Revision: 919790
- fix build with latest libtool: link with dlopen lib and remove old ltdl configure options
- buildrequire kernel-desktop devel instead of deprecated kirkwood flavor on ARM

* Tue Nov 10 2015 tmb <tmb> 6.27-1.mga6
+ Revision: 901458
- update to 6.27

* Mon Dec 01 2014 tmb <tmb> 6.24-1.mga5
+ Revision: 800235
- update to 6.24
- drop merged patches

* Thu Oct 30 2014 tmb <tmb> 6.23-3.mga5
+ Revision: 794766
- sync in upstream fixes for proper api bump matching the added symbols

* Fri Oct 24 2014 tmb <tmb> 6.23-2.mga5
+ Revision: 793034
- add missing ipset_parse_uint16 export
- add missing ipset_parse_tcp_udp_port (mga#12875)
+ luigiwalser <luigiwalser>
- 6.23

* Wed Oct 15 2014 umeabot <umeabot> 6.21.1-3.mga5
+ Revision: 740476
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 6.21.1-2.mga5
+ Revision: 680547
- Mageia 5 Mass Rebuild

* Thu Mar 13 2014 dams <dams> 6.21.1-1.mga5
+ Revision: 603115
- new version 6.21.1

* Sun Feb 23 2014 oden <oden> 6.20.1-1.mga5
+ Revision: 595945
- 6.20.1
- libify and make it utilize dl modules + devel package (#9061)

* Sat Oct 19 2013 umeabot <umeabot> 6.19-2.mga4
+ Revision: 532917
- Mageia 4 Mass Rebuild

* Fri Aug 23 2013 oden <oden> 6.19-1.mga4
+ Revision: 470309
- 6.19

* Sat Jan 12 2013 umeabot <umeabot> 6.16.1-2.mga3
+ Revision: 354464
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 tmb <tmb> 6.16.1-1.mga3
+ Revision: 339717
- update to 6.16.1

* Mon Mar 05 2012 tmb <tmb> 6.11-1.mga2
+ Revision: 219205
- update filelists
- update to 6.11

* Fri Jan 06 2012 tmb <tmb> 6.10-1.mga2
+ Revision: 192079
- update to 6.10
- drop defattr and old tarballs
- fix description
- update to 6.8

* Thu May 12 2011 pterjan <pterjan> 6.4-4.mga1
+ Revision: 97377
- Avoid hardcoding kernel version in BuildRequires

* Wed May 11 2011 pterjan <pterjan> 6.4-3.mga1
+ Revision: 97367
- Rebuild for new kernel

* Tue May 03 2011 tmb <tmb> 6.4-2.mga1
+ Revision: 94524
- disable shared build as nothing needs it (fwang, mdv)

* Sun Apr 24 2011 tmb <tmb> 6.4-1.mga1
+ Revision: 90137
- disable under/overlinking temporarily
- fix build to check against correct kernel config
- fix build
- add libmnl to requires and mnl-devel to buildrequires
- update to 6.4

* Fri Feb 11 2011 tmb <tmb> 4.4-1.mga1
+ Revision: 50080
- imported package ipset

